@@ -30,3 +30,14 @@ __all__ = ('Chemical', 'Chemicals', 'CompiledChemicals', 'Thermo', 'indexer',
            'Stream', 'MultiStream', 'ThermalCondition', 'mixture', 'ThermoData',
            'settings', 'functor', 'properties', 'base', 'equilibrium',
            'exceptions', 'functional', 'reaction', 'utils', 'speed_up')
+
+# Set number of digits displayed
+import numpy as np
+import pandas as pd
+np.set_printoptions(suppress=False)
+np.set_printoptions(precision=3) 
+pd.options.display.float_format = '{:.3g}'.format
+pd.set_option('display.max_rows', 35)
+pd.set_option('display.max_columns', 10)
+pd.set_option('max_colwidth', 35)
+del np, pd
\ No newline at end of file
