@@ -9,7 +9,7 @@ import thermosteam as tmo
 from . import indexer
 from . import equilibrium as eq
 from . import functional as fn
-from .base import units_of_measure as thermo_units
+from . import units_of_measure as thermo_units
 from .exceptions import DimensionError
 from . import utils
 
