@@ -4,7 +4,7 @@ Created on Wed Nov 13 10:06:46 2019
 
 @author: yoelr
 """
-from .units_of_measure import chemical_units_of_measure, definitions, types
+from ..units_of_measure import chemical_units_of_measure, definitions, types
 
 __all__ = ('Documenter', 'autodoc_functor')
 
