@@ -4,7 +4,7 @@ Created on Sat Oct 26 04:26:20 2019
 
 @author: yoelr
 """
-from .units_of_measure import chemical_units_of_measure
+from ..units_of_measure import chemical_units_of_measure
 from .. import utils
 from inspect import signature
 
