@@ -5,7 +5,7 @@ Created on Mon Dec  2 01:41:50 2019
 @author: yoelr
 """
 import thermosteam as tmo
-from .base import AbsoluteUnitsOfMeasure
+from .units_of_measure import AbsoluteUnitsOfMeasure
 from . import utils
 from .exceptions import UndefinedPhase, UndefinedChemical
 from ._phase import Phase, LockedPhase, NoPhase
