@@ -3,7 +3,7 @@
 All Mixture object builders.
 
 """
-from ..base import PhaseMixtureProperty
+from ..base import PhaseMixtureHandle
 from .ideal_mixture_model import IdealMixtureModel
 from .mixture import Mixture
 
@@ -11,30 +11,30 @@ __all__ = ('ideal_mixture',)
 
 # %% Functions
 
-def group_properties_by_phase(phase_properties):
+def group_handles_by_phase(phase_handles):
     hasfield = hasattr
     getfield = getattr
     iscallable = callable
-    properties_by_phase = {'s': [],
+    handles_by_phase = {'s': [],
                            'l': [],
                            'g': []}
-    for phase, properties in properties_by_phase.items():
-        for phase_property in phase_properties:
-            if iscallable(phase_property) and hasfield(phase_property, phase):
-                prop = getfield(phase_property, phase)
+    for phase, handles in handles_by_phase.items():
+        for phase_handle in phase_handles:
+            if iscallable(phase_handle) and hasfield(phase_handle, phase):
+                prop = getfield(phase_handle, phase)
             else:
-                prop = phase_property
-            properties.append(prop)
-    return properties_by_phase
+                prop = phase_handle
+            handles.append(prop)
+    return handles_by_phase
     
-def build_ideal_PhaseMixtureProperty(chemicals, var):
-    setfield = setattr
+def build_ideal_PhaseMixtureHandle(chemicals, var):
+    setfield = object.__setattr__
     getfield = getattr
-    phase_properties = [getfield(i, var) for i in chemicals]
-    new = PhaseMixtureProperty.__new__(PhaseMixtureProperty)
-    for phase, properties in group_properties_by_phase(phase_properties).items():
-        setfield(new, phase, IdealMixtureModel(properties, var))
-    new.var = var
+    phase_handles = [getfield(i, var) for i in chemicals]
+    new = PhaseMixtureHandle.__new__(PhaseMixtureHandle)
+    for phase, handles in group_handles_by_phase(phase_handles).items():
+        setfield(new, phase, IdealMixtureModel(handles, var))
+    setfield(new, 'var', var)
     return new
 
 # %% Ideal mixture model builder 
@@ -72,14 +72,14 @@ def ideal_mixture(chemicals,
     """
     chemicals = tuple(chemicals)
     getfield = getattr
-    Cn =  build_ideal_PhaseMixtureProperty(chemicals, 'Cn')
-    H =  build_ideal_PhaseMixtureProperty(chemicals, 'H')
-    S = build_ideal_PhaseMixtureProperty(chemicals, 'S')
-    H_excess = build_ideal_PhaseMixtureProperty(chemicals, 'H_excess')
-    S_excess = build_ideal_PhaseMixtureProperty(chemicals, 'S_excess')
-    mu = build_ideal_PhaseMixtureProperty(chemicals, 'mu')
-    V = build_ideal_PhaseMixtureProperty(chemicals, 'V')
-    kappa = build_ideal_PhaseMixtureProperty(chemicals, 'kappa')
+    Cn =  build_ideal_PhaseMixtureHandle(chemicals, 'Cn')
+    H =  build_ideal_PhaseMixtureHandle(chemicals, 'H')
+    S = build_ideal_PhaseMixtureHandle(chemicals, 'S')
+    H_excess = build_ideal_PhaseMixtureHandle(chemicals, 'H_excess')
+    S_excess = build_ideal_PhaseMixtureHandle(chemicals, 'S_excess')
+    mu = build_ideal_PhaseMixtureHandle(chemicals, 'mu')
+    V = build_ideal_PhaseMixtureHandle(chemicals, 'V')
+    kappa = build_ideal_PhaseMixtureHandle(chemicals, 'kappa')
     Hvap = IdealMixtureModel([getfield(i, 'Hvap') for i in chemicals], 'Hvap')
     sigma = IdealMixtureModel([getfield(i, 'sigma') for i in chemicals], 'sigma')
     epsilon = IdealMixtureModel([getfield(i, 'epsilon') for i in chemicals], 'epsilon')
