@@ -24,9 +24,17 @@ from cmath import log as clog
 from cmath import sqrt as csqrt
 from scipy.special import hyp2f1
 
-@functor(ref='[1]_')
+@functor
 def DIPPR_EQ100(T, a=0., b=0., c=0., d=0., e=0., f=0., g=0.):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ100 method,
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,e,f,g : float
+        Regressed coefficients.
+    
     See also
     --------
     DIPPR_EQ100_derivative_by_T
@@ -67,8 +75,8 @@ def DIPPR_EQ100(T, a=0., b=0., c=0., d=0., e=0., f=0., g=0.):
     >>> EQ100( 276370., -2090.1, 8.125, -0.014116, 0.0000093701)
     >>> EQ100(300)
     75355.81000000003
-
-    '''
+    
+    """
     return a + T*(b + T*(c + T*(d + T*(e + T*(f + g*T)))))
  
 @functor   
@@ -86,9 +94,17 @@ def DIPPR_EQ100_integral_by_T_over_T(T, a=0., b=0., c=0., d=0., e=0., f=0., g=0.
     """T-Integral of DPPR Equation #100 divided by T."""
     return a*log(T) + T*(b + T*(c/2 + T*(d/3 + T*(e/4 + T*(f/5 + g*T/6)))))
 
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ101(T, a, b, c, d, e):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ101 method,
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,e : float
+        Regressed coefficients.
+    
     Notes
     -----
     DIPPR Equation # 101. Used in calculating vapor pressure, sublimation
@@ -110,12 +126,20 @@ def DIPPR_EQ101(T, a, b, c, d, e):
     >>> f(300)
     3537.44834545549
     
-    '''
+    """
     return exp(a + b/T + c*log(T) + d*T**e)
 
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ102(T, a, b, c, d):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ102 method,
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,e : float
+        Regressed coefficients.
+    
     See also
     --------
     DIPPR_EQ102_derivative_by_T
@@ -164,7 +188,7 @@ def DIPPR_EQ102(T, a, b, c, d):
     >>> f(300)
     9.860384711890639e-06
     
-    '''
+    """
     return a*T**b/(1. + c/T + d/(T*T))
 
 def DIPPR_EQ102_derivative_by_T(T, a, b, c, d):
@@ -187,9 +211,17 @@ def DIPPR_EQ102_integral_by_T_over_T(T, a, b, c, d):
         hyp2f1(1, 2+b, 3+b, -2*T/(c + csqrt(c*c - 4*d)))/((2+b)*(c + csqrt(
                             c*c-4*d))*csqrt(c*c-4*d))).real
         
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ104(T, a, b, c, d, e):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ104 method,
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,e : float
+        Regressed coefficients.
+    
     See also
     --------
     DIPPR_EQ104_derivative_by_T
@@ -228,7 +260,7 @@ def DIPPR_EQ104(T, a, b, c, d, e):
     >>> f(300)
     -1.1204179007265156
     
-    '''
+    """
     T2 = T*T
     return a + (b + (c + (d + e/T)/(T2*T2*T))/T2)/T
 
@@ -250,9 +282,17 @@ def DIPPR_EQ104_integral_by_T_over_T(T, a, b, c, d, e):
     return a*log(T) - (72*b*T**8 + 24*c*T**6 + 9*d*T + 8*e)/(72*T**9)
     
 
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ105(T, a, b, c, d, vol=False):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ105 method,
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,vol : float
+        Regressed coefficients.
+    
     Notes
     -----
     DIPPR Equation #105. Often used in calculating liquid molar density.
@@ -272,15 +312,25 @@ def DIPPR_EQ105(T, a, b, c, d, vol=False):
     >>> f(300.)
     7.593170096339236
     
-    '''
+    """
     if vol:
         return b**(1. + (1. - T/c)**d)/a
     else:
         return a/b**(1. + (1. - T/c)**d)
 
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ106(T, Tc, a, b, c=0, d=0, e=0):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ106 method,
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    a,b,c,d,e : float
+        Regressed coefficients.
+    
     Notes
     -----
     DIPPR Equation #106. Often used in calculating liquid surface tension,
@@ -303,13 +353,21 @@ def DIPPR_EQ106(T, Tc, a, b, c=0, d=0, e=0):
     >>> f(300)
     0.07231499373541
     
-    '''
+    """
     Tr = T/Tc
     return a*(1. - Tr)**(b + Tr*(c + Tr*(d + e*Tr)))
 
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ107(T, a=0, b=0, c=0, d=0, e=0):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ107 method,
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,e : float
+        Regressed coefficients.
+    
     See also
     --------
     DIPPR_EQ107_derivative_by_T
@@ -355,7 +413,7 @@ def DIPPR_EQ107(T, a=0, b=0, c=0, d=0, e=0):
     >>> f(300.)
     33585.90452768923
     
-    '''
+    """
     return a + b*((c/T)/sinh(c/T))**2 + d*((e/T)/cosh(e/T))**2
 
 @functor
@@ -377,9 +435,20 @@ def DIPPR_EQ107_integral_by_T_over_T(T, a=0, b=0, c=0, d=0, e=0):
                 - d*e*tanh(e/T)/T + d*log(cosh(e/T)))
 
 
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ114(T, Tc, a, b, c, d):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ114 method, 
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    a,b,c,d : float
+        Regressed coefficients.
+    
+    
     See also
     --------
     DIPPR_EQ114_derivative_by_T
@@ -447,7 +516,7 @@ def DIPPR_EQ114(T, Tc, a, b, c, d):
     >>> f(20)
     19423.948911676463
     
-    '''
+    """
     t = 1.-T/Tc
     return (a**2./t + b - 2.*a*c*t - a*d*t**2. - c**2.*t**3./3. 
             - c*d*t**4./2. - d**2*t**5./5.)
@@ -484,9 +553,17 @@ def DIPPR_EQ114_integral_by_T_over_T(T, Tc, a, b, c, d):
                - 6*d**2))/(60*a**2 - 60*a*c - 30*a*d + 30*b - 10*c**2 
                     - 15*c*d - 6*d**2)).real/30)
 
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ115(T, a, b, c=0, d=0, e=0):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ115 method, 
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,e : float
+        Regressed coefficients.
+    
     Notes
     -----
     DIPPR Equation #115. No major uses; has been used as an alternate
@@ -499,13 +576,24 @@ def DIPPR_EQ115(T, a, b, c=0, d=0, e=0):
     No coefficients found for this expression.
     This function is not integrable for either dT or Y/T dT.
     
-    '''
+    """
     T2 = T**2
     return exp(a+b/T+c*log(T)+d*T2 + e/T2)
 
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ116(T, Tc, a, b, c, d, e):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ116 method,
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    a,b,c,d,e : float
+        Regressed coefficients.
+    
+    
     See also
     --------
     DIPPR_EQ116_derivative_by_T
@@ -548,7 +636,7 @@ def DIPPR_EQ116(T, Tc, a, b, c, d, e):
     >>> f(300.)
     55.17615446406527
     
-    '''
+    """
     tau = 1-T/Tc
     return a + b*tau**0.35 + c*tau**(2/3.) + d*tau + e*tau**(4/3.)
 
@@ -620,9 +708,17 @@ def DIPPR_EQ116_integral_by_T_over_T(T, Tc, a, b, c, d, e):
     x47 = x35 - x37 + 2
     return a*x0 + 2.85714285714286*b*x4**0.35 - c*x1 + c*x11 + d*x0 - d*x3 - e*x1 - e*x11 + 0.75*e*x4**1.33333333333333 + 3*e*x6 + 1.5*e*x9 - x15*atan(x14*(x16 + x17)) + x15*atan(x14*(x16 + x18)) - x21*atan(x20*(x17 + x22)) + x21*atan(x20*(x18 + x22)) + x23*atan(x24*(x25 + x26)) - x23*atan(x24*(x25 + x27)) - x28*atan(x31*(x26 + x32)) + x28*atan(x31*(x27 + x32)) - x33*log(x36 - x38) + x33*log(x36 + x38) + x39*log(x36 - x40) - x39*log(x36 + x40) + x4**0.666666666666667*x5 - x42*log(x43 + x44) + x42*log(x46 + x47) + x45*log(x43 + x47) - x45*log(x44 + x46) + x5*x9 + x7*atan(x8) - x7*atanh(x8)
 
-@functor(ref="[1]_")
+@functor
 def DIPPR_EQ127(T, a, b, c, d, e, f, g):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) based on the DIPPR EQ127 method,
+    as described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,e,f,g : float
+        Regressed coefficients.
+    
     See also
     --------
     DIPPR_EQ127_derivative_by_T
@@ -684,7 +780,7 @@ def DIPPR_EQ127(T, a, b, c, d, e, f, g):
     >>> f(20.)
     33258.0
     
-    '''
+    """
     return (a+b*((c/T)**2*exp(c/T)/(exp(c/T) - 1)**2) + 
         d*((e/T)**2*exp(e/T)/(exp(e/T)-1)**2) + 
         f*((g/T)**2*exp(g/T)/(exp(g/T)-1)**2))
