@@ -30,7 +30,7 @@ import numpy as np
 import os
 import re
 import string
-from ..utils import load_json
+from .readers import load_json
 
 fpath = os.path
 join = fpath.join
