@@ -43,11 +43,20 @@ from ..base import (InterpolatedTDependentModel,
                     PhaseTHandleBuilder, 
                     thermo_model, 
                     functor)
-from ..utils import load_json
-from .utils import to_nums, CASDataReader
+from .data import (Cn_data_Poling,
+                   Cn_data_TRC_gas,
+                   Cn_data_CRC_standard,
+                   Cn_data_PerryI,
+                   zabransky_dict_sat_s,
+                   zabransky_dict_sat_p,
+                   zabransky_dict_const_s,
+                   zabransky_dict_const_p,
+                   zabransky_dict_iso_s,
+                   zabransky_dict_iso_p,
+                   VDI_saturation_dict, 
+                   VDI_tabular_data)
 from .._constants import R, calorie
 from ..functional import polylog2
-from .miscdata import VDI_saturation_dict, VDI_tabular_data
 # from .electrochem import (LaliberteHeatCapacityModel,
 #                           _Laliberte_Heat_Capacity_ParametersDict)
 # from .coolprop import has_CoolProp, coolprop_dict, CoolProp_T_dependent_property,\
@@ -124,25 +133,6 @@ class ZabranskyModelBuilder:
         return CnHSModel(*self.funcs, args, Tmin, Tmax, self.name)
 
 
-# %% Data
-
-read = CASDataReader(__file__, 'Heat Capacity')
-_Poling = read('PolingDatabank.tsv')
-_TRC_gas = read('TRC Thermodynamics of Organic Compounds in the Gas State.tsv')
-_CRC_standard = read('CRC Standard Thermodynamic Properties of Chemical Substances.tsv')
-_PerryI = load_json(read.folder, 'Perrys Table 2-151.json')
-# Read in a dict of heat capacities of irnorganic and elemental solids.
-# These are in section 2, table 151 in:
-# Green, Don, and Robert Perry. Perry's Chemical Engineers' Handbook,
-# Eighth Edition. McGraw-Hill Professional, 2007.
-
-# Formula:
-# Cn(Cal/mol/K) = Const + Lin*T + Quadinv/T^2 + Quadinv*T^2
-
-# Phases: c, gls, l, g.
-
-
-
 # %% Heat Capacities Gas
  
 def calculate_Lastovka_Shaw_term(iscyclic_aliphatic, similary_variable):
@@ -451,19 +441,19 @@ Poling_Functors = (Poling,
 @TDependentHandleBuilder('Cn.g')
 def heat_capacity_gas_handle(handle, CAS, MW, similarity_variable, iscyclic_aliphatic):
     add_model = handle.add_model
-    if CAS in _TRC_gas:
-        _, Tmin, Tmax, a0, a1, a2, a3, a4, a5, a6, a7, _, _, _ = _TRC_gas[CAS]
+    if CAS in Cn_data_TRC_gas:
+        _, Tmin, Tmax, a0, a1, a2, a3, a4, a5, a6, a7, _, _, _ = Cn_data_TRC_gas[CAS]
         funcs = CnHS(*TRCCn_Functors, (a0, a1, a2, a3, a4, a5, a6, a7))
         add_model(Tmin=Tmin, Tmax=Tmax, name=TRCIG, **funcs)
-    if CAS in _Poling:
-        _, Tmin, Tmax, a, b, c, d, e, Cn_g, _ = _Poling[CAS]
+    if CAS in Cn_data_Poling:
+        _, Tmin, Tmax, a, b, c, d, e, Cn_g, _ = Cn_data_Poling[CAS]
         if not np.isnan(a):
             funcs = CnHS(*Poling_Functors, (a, b, c, d, e))
             add_model(Tmin=Tmin, Tmax=Tmax, **funcs, name=POLING)
         if not np.isnan(Cn_g):
             add_model(Cn_g, Tmin, Tmax, name=POLING_CONST)
-    if CAS in _CRC_standard:
-        Cn_g = _CRC_standard[CAS][-1]
+    if CAS in Cn_data_CRC_standard:
+        Cn_g = Cn_data_CRC_standard[CAS][-1]
         if not np.isnan(Cn_g):
             add_model(Cn_g, name=CRCSTD)
     if MW and similarity_variable:
@@ -648,40 +638,6 @@ def Dadgostar_Shaw_Over_T_Integral(Ta, Tb, MW, similarity_variable):
     return MW*(Dadgostar_Shaw_Over_T_Indefinte_Integral(Tb, *terms)
                - Dadgostar_Shaw_Over_T_Indefinte_Integral(Ta, *terms))
 
-zabransky_dict_sat_s = {}
-zabransky_dict_sat_p = {}
-zabransky_dict_const_s = {}
-zabransky_dict_const_p = {}
-zabransky_dict_iso_s = {}
-zabransky_dict_iso_p = {}
-
-# C means average heat capacity values, from less rigorous experiments
-# sat means heat capacity along the saturation line
-# p means constant-pressure values, 
-# second argument is whether or not it has a spline
-type_to_zabransky_dict = {('C', True): zabransky_dict_const_s, 
-                          ('C', False):   zabransky_dict_const_p,
-                          ('sat', True):  zabransky_dict_sat_s,
-                          ('sat', False): zabransky_dict_sat_p,
-                          ('p', True):    zabransky_dict_iso_s,
-                          ('p', False):   zabransky_dict_iso_p}
-
-with open(os.path.join(read.folder, 'Zabransky.tsv'), encoding='utf-8') as f:
-    next(f)
-    for line in f:
-        values = to_nums(line.strip('\n').split('\t'))
-        (CAS, name, Type, uncertainty, Tmin, Tmax, a1s, a2s, a3s, a4s, a1p, a2p, a3p, a4p, a5p, a6p, Tc) = values
-        spline = bool(a1s) # False if Quasypolynomial, True if spline
-        d = type_to_zabransky_dict[(Type, spline)]
-        if spline:
-            if CAS not in d:
-                d[CAS] = [(a1s, a2s, a3s, a4s, Tmin, Tmax)]
-            else:
-                d[CAS].append((a1s, a2s, a3s, a4s, Tmin, Tmax))
-        else:
-            # No duplicates for quasipolynomials
-            d[CAS] = (Tc, a1p, a2p, a3p, a4p, a5p, a6p, Tmin, Tmax)
-
 @functor(var='Cn.l')
 def Zabransky_Quasi_Polynomial(T, Tc, a1, a2, a3, a4, a5, a6):
     r"""
@@ -850,12 +806,12 @@ def heat_capacity_liquid_handle(handle, CAS, Tb, Tc, omega, MW, similarity_varia
                                data=(MW, similarity_variable),
                                name=DADGOSTAR_SHAW))
     # Constant models
-    if CAS in _Poling:
-        _, Tmin, Tmax, a, b, c, d, e, Cn_g, Cn_l = _Poling[CAS]
+    if CAS in Cn_data_Poling:
+        _, Tmin, Tmax, a, b, c, d, e, Cn_g, Cn_l = Cn_data_Poling[CAS]
         if not np.isnan(Cn_g):
             add_model(Cn_l, Tmin, Tmax, name=POLING_CONST)
-    if CAS in _CRC_standard:
-        Cn_l = _CRC_standard[CAS][-5]
+    if CAS in Cn_data_CRC_standard:
+        Cn_l = Cn_data_CRC_standard[CAS][-5]
         if not np.isnan(Cn_l):
             add_model(Cn_l, 0, Tc, name=CRCSTD)
 
@@ -1019,8 +975,8 @@ def heat_capacity_solid_handle(handle, CAS, similarity_variable, MW):
     Tmin = 0
     Tmax = 2000
     add_model = handle.add_model
-    if CAS in _PerryI:
-        vals = _PerryI[CAS]
+    if CAS in Cn_data_PerryI:
+        vals = Cn_data_PerryI[CAS]
         if 'c' in vals:
             c = vals['c']
             Tmin = c['Tmin']
@@ -1028,8 +984,8 @@ def heat_capacity_solid_handle(handle, CAS, similarity_variable, MW):
             data = (c['Const'], c['Lin'], c['Quad'], c['Quadinv'])
             add_model(CnHSModel(*Perry_151_Functors, data), Tmin, Tmax,
                       name=PERRY151)
-    if CAS in _CRC_standard:
-        Cnc = _CRC_standard[CAS][3]
+    if CAS in Cn_data_CRC_standard:
+        Cnc = Cn_data_CRC_standard[CAS][3]
         if not np.isnan(Cnc):
             add_model(float(Cnc), 200, 350)
     if similarity_variable and MW:
