@@ -69,45 +69,22 @@ import numpy as np
 from ..base import InterpolatedTDependentModel, TDependentHandleBuilder, functor
 from .._constants import R, N_A
 from math import log, pi
-from .utils import CASDataReader, get_from_data_sources
-from .miscdata import organic_data_CRC, inorganic_data_CRC
-from .miscdata import VDI_saturation_dict, VDI_tabular_data
 from .. import functional as fn
 from .dippr import DIPPR_EQ106
-
-read = CASDataReader(__file__, 'Phase Change')
-
-boiling_point_data_Yaws = read('Yaws Boiling Points.tsv')
-melting_point_data_ON = read('OpenNotebook Melting Points.tsv')
-vaporization_data_Gharagheizi = read('Ghazerati Appendix Vaporization Enthalpy.tsv')
-vaporization_data_CRC = read('CRC Handbook Heat of Vaporization.tsv')
-fusion_data_CRC = read('CRC Handbook Heat of Fusion.tsv')
-sublimation_data_Gharagheizi = read('Ghazerati Appendix Sublimation Enthalpy.tsv')
-vaporization_data_Perrys2_150 = read('Table 2-150 Heats of Vaporization of Inorganic and Organic Liquids.tsv')
-vaporization_data_VDI_PPDS_4 = read('VDI PPDS Enthalpies of vaporization.tsv')
-vaporization_data_Alibakhshi_Cs = read('Alibakhshi one-coefficient enthalpy of vaporization.tsv')
-
-### Boiling Point at 1 atm
-
-normal_boiling_point_data_sources = {
-    'CRC-Inorganic': inorganic_data_CRC,
-    'CRC-Organic': organic_data_CRC,
-    'Yaws': boiling_point_data_Yaws,
-}
-
-melting_point_data_sources = {
-    'OPEN-NTBKM': melting_point_data_ON,  
-    'CRC-Inorganic': inorganic_data_CRC,
-    'CRC-Organic': organic_data_CRC,   
-}
-
-fusion_data_sources = {
-    'CRC at Tm': fusion_data_CRC,
-}
-
-sublimation_data_sources = {
-    'Ghazerati Appendix, at 298K': sublimation_data_Gharagheizi,
-}
+from .data import (get_from_data_sources,
+                   normal_boiling_point_data_sources,
+                   melting_point_data_sources,
+                   vaporization_data_Perrys2_150,
+                   vaporization_data_VDI_PPDS_4,
+                   VDI_saturation_dict,
+                   vaporization_data_Alibakhshi_Cs,
+                   VDI_tabular_data,
+                   vaporization_data_CRC,
+                   vaporization_data_Gharagheizi,
+                   fusion_data_sources,
+                   sublimation_data_sources,
+)
+                   
 
 
 def normal_boiling_point_temperature(CASRN, method='Any'):
