@@ -20,32 +20,19 @@ References
     
 '''
 
-__all__ = ('API_TDB_data', 
-           'ATcT_l', 'ATcT_g', 
-           'heat_of_formation', 
+__all__ = ('heat_of_formation', 
            'heat_of_formation_liquid',
            'heat_of_formation_gas',
 )
            
-from .heat_capacity import _TRC_gas
-from .utils import CASDataReader, get_from_data_sources
-
-read = CASDataReader(__file__, "Reactions")
-API_TDB_data = read('API TDB Albahri Hf.tsv')
-ATcT_l = read('ATcT 1.112 (l).tsv')
-ATcT_g = read('ATcT 1.112 (g).tsv')
+from .data import (Cn_data_TRC_gas, 
+                   Hf_data_ATcT_g,
+                   heat_of_formation_sources,
+                   heat_of_formation_liquid_sources,
+                   get_from_data_sources
+)
 
 
-heat_of_formation_sources = {
-    'API_TDB': API_TDB_data
-}
-heat_of_formation_liquid_sources = {
-    'ATCT_L': ATcT_l
-}
-heat_of_formation_gas_sources = {
-    'ATCT_G': ATcT_g,
-    'TRC': _TRC_gas,
-}
 
 def heat_of_formation(CASRN, phase_ref=None, method='Any'):
     r'''
@@ -180,17 +167,17 @@ def heat_of_formation_gas(CASRN, method='Any'):
 
     '''
     if method == 'All':
-        Hf_g = {'ATCT_G': ATcT_g.retrieve(CASRN, 'Hf_298K'),
-              'TRC': _TRC_gas.retrieve(CASRN, 'Hf'),
+        Hf_g = {'ATCT_G': Hf_data_ATcT_g.retrieve(CASRN, 'Hf_298K'),
+              'TRC': Cn_data_TRC_gas.retrieve(CASRN, 'Hf'),
               }
     elif method == 'Any':
-        Hf_g = ATcT_g.retrieve(CASRN, 'Hf_298K')
+        Hf_g = Hf_data_ATcT_g.retrieve(CASRN, 'Hf_298K')
         if Hf_g is None:
-            Hf_g = _TRC_gas.retrieve(CASRN, 'Hf')
+            Hf_g = Cn_data_TRC_gas.retrieve(CASRN, 'Hf')
     elif method == 'ATCT_G':
-        Hf_g = ATcT_g.retrieve(CASRN, 'Hf_298K')
+        Hf_g = Hf_data_ATcT_g.retrieve(CASRN, 'Hf_298K')
     elif method == 'TRC':
-        Hf_g = _TRC_gas.retrieve(CASRN, 'Hf')
+        Hf_g = Cn_data_TRC_gas.retrieve(CASRN, 'Hf')
     else:
         raise ValueError("invalid method; method must be one of the following: "
                          "'TRC', or 'ATCT_G'.")
