@@ -69,9 +69,14 @@ from ..base import (InterpolatedTDependentModel,
                     functor)
 from .._constants import R, N_A, k
 from math import log, exp
-from .utils import CASDataReader
 from ..functional import horner_polynomial
-from .miscdata import VDI_saturation_dict, VDI_tabular_data
+from .data import (VDI_saturation_dict,
+                   VDI_tabular_data,
+                   # kappa_data_Perrys2_314,
+                   kappa_data_Perrys2_315,
+                   kappa_data_VDI_PPDS_9,
+                   # kappa_data_VDI_PPDS_10,
+)
 from .dippr import DIPPR_EQ100
 
 __all__ = ('thermal_conductivity_handle',
@@ -98,12 +103,7 @@ __all__ = ('thermal_conductivity_handle',
            'Chung_dense',
 )
 
-read = CASDataReader(__file__, 'Thermal Conductivity')
 
-_Perrys2_314 = read('Table 2-314 Vapor Thermal Conductivity of Inorganic and Organic Substances.tsv')
-_Perrys2_315 = read('Table 2-315 Thermal Conductivity of Inorganic and Organic Liquids.tsv')
-_VDI_PPDS_9 = read('VDI PPDS Thermal conductivity of saturated liquids.tsv')
-_VDI_PPDS_10 = read('VDI PPDS Thermal conductivity of gases.tsv')
 ### Purely CSP Methods - Liquids
 
 @functor(var='kappa.l')
@@ -525,12 +525,12 @@ def thermal_conductivity_liquid_handle(handle, CAS, MW, Tm, Tb, Tc, Pc, omega):
         data = (Tc, Pc, handle)
         add_model(DIPPR9G.from_args(data))
         add_model(Missenard.from_args(data))
-    if CAS in _Perrys2_315:
-        _, C1, C2, C3, C4, C5, Tmin, Tmax = _Perrys2_315[CAS]
+    if CAS in kappa_data_Perrys2_315:
+        _, C1, C2, C3, C4, C5, Tmin, Tmax = kappa_data_Perrys2_315[CAS]
         data = (C1, C2, C3, C4, C5)
         add_model(DIPPR_EQ100.from_args(data), Tmin, Tmax)
-    if CAS in _VDI_PPDS_9:
-        _,  A, B, C, D, E = _VDI_PPDS_9[CAS]
+    if CAS in kappa_data_VDI_PPDS_9:
+        _,  A, B, C, D, E = kappa_data_VDI_PPDS_9[CAS]
         add_model(horner_polynomial.from_kwargs({'coeffs':(E, D, C, B, A)}))
     if CAS in VDI_saturation_dict:
         Ts, Ys = VDI_tabular_data(CAS, 'K (l)')
@@ -1239,8 +1239,8 @@ def thermal_conductivity_gas_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega,
     if CAS in VDI_saturation_dict:
         Ts, Ys = VDI_tabular_data(CAS, 'K (g)')
         add_model(InterpolatedTDependentModel(Ts, Ys))
-    # if CAS in _VDI_PPDS_10:
-    #     _,  *data = _VDI_PPDS_10[CAS].tolist()
+    # if CAS in kappa_data_VDI_PPDS_10:
+    #     _,  *data = kappa_data_VDI_PPDS_10[CAS].tolist()
     #     data.reverse()
     #     add_model(horner_polynomial.from_kwargs({'coeffs': data}))
     data = (MW, Cn, mug, Tc)
@@ -1269,8 +1269,8 @@ def thermal_conductivity_gas_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega,
         add_model(Eucken_modified.from_args(data))
         add_model(Eucken.from_args(data))
     # TODO: Fix propblem with values
-    # if CAS in _Perrys2_314:
-    #     _, *data, Tmin, Tmax = _Perrys2_314[CAS]
+    # if CAS in kappa_data_Perrys2_314:
+    #     _, *data, Tmin, Tmax = kappa_data_Perrys2_314[CAS]
     #     add_model(DIPPR9B_linear(data), Tmin, Tmax)
 
 thermal_conductivity_handle = PhaseTPHandleBuilder('kappa', None,
